import React, { useState, useEffect } from 'react';
import ClassSelection from './components/ClassSelection';
import PetDisplay from './components/PetDisplay';
import InteractionMenu from './components/InteractionMenu';
import { Pet, PetClassInfo } from './types/Pet';
import { fetchPets, createPet } from './services/api/api';

export default function App() {
  const [pet, setPet] = useState<Pet | null>(null);
  const [showConfirmation, setShowConfirmation] = useState(false);
  const [showNameModal, setShowNameModal] = useState(false);
  const [petName, setPetName] = useState('');
  const [selectedClass, setSelectedClass] = useState<{ key: string; info: PetClassInfo } | null>(null);

  useEffect(() => {
    const loadPets = async () => {
      try {
        const pets = await fetchPets();
        if (pets.length > 0) {
          setPet(pets[0]);
        }
      } catch (error) {
        console.error('Error loading pets:', error);
      }
    };

    loadPets();
  }, []);

  const handleClassSelect = (classKey: string, classInfo: PetClassInfo) => {
    setSelectedClass({ key: classKey, info: classInfo });
    setShowConfirmation(true);
  };

  const handleConfirm = () => {
    if (!selectedClass) return;
    setShowConfirmation(false);
    setShowNameModal(true);
    setPetName('');
  };

  const handleNameSubmit = async () => {
    if (!selectedClass || !petName.trim()) return;

    try {
      const newPet = await createPet({
        name: petName.trim(),
        class: selectedClass.key,
      });
      setPet(newPet);
      setShowNameModal(false);
    } catch (error) {
      console.error('Error creating pet:', error);
    }
  };

  const handleFeed = () => {
    if (!pet) return;
    setPet({
      ...pet,
      stats: {
        ...pet.stats,
        strength: Math.min(100, pet.stats.strength + 5)
      },
      resources: {
        ...pet.resources,
        food: Math.max(0, pet.resources.food - 10)
      }
    });
  };

  const handlePlay = () => {
    if (!pet) return;
    setPet({
      ...pet,
      stats: {
        ...pet.stats,
        charisma: Math.min(100, pet.stats.charisma + 5)
      },
      resources: {
        ...pet.resources,
        wisdom: pet.resources.wisdom + 5
      }
    });
  };

  const handleSleep = () => {
    if (!pet) return;
    setPet({
      ...pet,
      stats: {
        intelligence: Math.min(100, pet.stats.intelligence + 5),
        strength: Math.min(100, pet.stats.strength + 2),
        charisma: Math.min(100, pet.stats.charisma + 2)
      }
    });
  };

  const handleCustomize = () => {
    console.log('Customize pet');
  };

  if (!pet) {
    return (
      <div className="min-h-screen bg-gray-900 text-white">
        {showNameModal && selectedClass ? (
          <div className="fixed inset-0 bg-black/50 backdrop-blur-sm flex items-center justify-center p-4">
            <div className="bg-gray-800 p-6 rounded-xl max-w-md w-full">
              <h2 className="text-2xl font-bold mb-2">Name Your Pet</h2>
              <p className="text-gray-400 mb-6">
                Creating a new {selectedClass.info.name.toLowerCase()} pet
              </p>
              <div className="space-y-4">
                <div>
                  <label htmlFor="petName" className="block text-sm font-medium text-gray-300 mb-2">
                    Pet Name
                  </label>
                  <input
                    type="text"
                    id="petName"
                    value={petName}
                    onChange={(e) => setPetName(e.target.value)}
                    className="w-full px-4 py-2 bg-gray-700 border border-gray-600 rounded-lg focus:ring-2 focus:ring-blue-500 focus:border-transparent"
                    placeholder="Enter a name for your pet"
                    autoFocus
                  />
                </div>
                <div className="flex space-x-4">
                  <button
                    onClick={handleNameSubmit}
                    disabled={!petName.trim()}
                    className={`flex-1 px-4 py-2 rounded-lg ${
                      petName.trim()
                        ? 'bg-blue-600 hover:bg-blue-700'
                        : 'bg-blue-600/50 cursor-not-allowed'
                    }`}
                  >
                    Create Pet
                  </button>
                  <button
                    onClick={() => {
                      setShowNameModal(false);
                      setSelectedClass(null);
                    }}
                    className="flex-1 px-4 py-2 bg-gray-600 hover:bg-gray-700 rounded-lg"
                  >
                    Cancel
                  </button>
                </div>
              </div>
            </div>
          </div>
        ) : showConfirmation && selectedClass ? (
          <div className="fixed inset-0 bg-black/50 flex items-center justify-center p-4">
            <div className="bg-gray-800 p-6 rounded-xl max-w-md w-full">
              <h2 className="text-2xl font-bold mb-4">Confirm Selection</h2>
              <p className="mb-4">Are you sure you want to choose {selectedClass.info.name}?</p>
              <div className="space-y-2 mb-6">
                {selectedClass.info.modifiers.map((modifier, index) => (
                  <div key={index} className="text-sm text-gray-300">• {modifier}</div>
                ))}
              </div>
              <div className="flex space-x-4">
                <button
                  onClick={handleConfirm}
                  className="flex-1 bg-blue-600 hover:bg-blue-700 px-4 py-2 rounded"
                >
                  Confirm
                </button>
                <button
                  onClick={() => {
                    setShowConfirmation(false);
                    setSelectedClass(null);
                  }}
                  className="flex-1 bg-gray-600 hover:bg-gray-700 px-4 py-2 rounded"
                >
                  Cancel
                </button>
              </div>
            </div>
          </div>
        ) : (
          <ClassSelection onSelect={handleClassSelect} />
        )}
      </div>
    );
  }

  return (
    <div className="min-h-screen bg-gray-900 text-white p-4">
      <div className="max-w-4xl mx-auto grid gap-8">
        <PetDisplay pet={pet} />
        <InteractionMenu
          pet={pet}
          onFeed={handleFeed}
          onPlay={handlePlay}
          onSleep={handleSleep}
          onCustomize={handleCustomize}
        />
      </div>
    </div>
  );
}